@@ -1,9 +1,8 @@
 #!/bin/sh
 #
 # Project    : ipv6calc/databases/registries
-# File       : update-registries.sh
-# Version    : $Id: 701542322dc99f2eb7a9cb2f4e92692f71499145 $
-# Copyright  : 2002-2021 by Peter Bieringer <pb (at) bieringer.de>
+# File       : ipv6calc-update-registries.sh
+# Copyright  : 2002-2024 by Peter Bieringer <pb (at) bieringer.de>
 #               replaces ../ipv4-assignment/update-ipv4-assignment.sh
 #               replaces ../ipv6-assignment/update-ipv6-assignment.sh
 #
@@ -109,7 +108,7 @@ get_urls | while read subdir url filename format flag; do
 		$dry_run || wget $wget_options $url$filename -O $filename
 		retval=$?
 	else
-		$dry_run || wget $wget_options $url$filename --timestamping --retr-symlinks
+		$dry_run || wget $wget_options $url$filename -N
 		retval=$?
 	fi
 	popd >/dev/null
